@@ -12,7 +12,7 @@ the full text of the license.
 '''
 
 import subprocess, tempfile, os.path, urllib, re, pwd, grp, os, sys
-import fnmatch, glob, atexit
+import fnmatch, glob, atexit, traceback
 
 import xml.dom, xml.dom.minidom
 from xml.parsers.expat import ExpatError
@@ -331,7 +331,8 @@ class Report(ProblemReport):
           the ones mentioned in extraenv)
         - ProcCmdline: /proc/pid/cmdline contents
         - ProcStatus: /proc/pid/status contents
-        - ProcMaps: /proc/pid/maps contents'''
+        - ProcMaps: /proc/pid/maps contents
+        - ProcAttrCurrent: /proc/pid/attr/current contents'''
 
         if not pid:
             pid = os.getpid()
@@ -358,6 +359,13 @@ class Report(ProblemReport):
         # make ProcCmdline ASCII friendly, do shell escaping
         self['ProcCmdline'] = self['ProcCmdline'].replace('\\', '\\\\').replace(' ', '\\ ').replace('\0', ' ')
 
+        # grab AppArmor or SELinux context
+        # If no LSM is loaded, reading will return -EINVAL
+        try:
+            self['ProcAttrCurrent'] = open('/proc/' + pid + '/attr/current').read().strip()
+        except (IOError, OSError):
+            pass
+
     def add_proc_environ(self, pid=None, extraenv=[]):
         '''Add environment information.
 
@@ -522,6 +530,8 @@ class Report(ProblemReport):
                 execfile(hook, symb)
                 symb['add_info'](self)
             except:
+                print >> sys.stderr, 'hook %s crashed:' % hook
+                traceback.print_exc()
                 pass
 
         # binary package hook
@@ -570,7 +580,14 @@ class Report(ProblemReport):
         try:
             patterns = urllib.urlopen('%s/%s.xml' % (baseurl, package)).read()
         except:
-            return None
+            # try if there is one for the source package
+            if self.has_key('SourcePackage'):
+                try:
+                    patterns = urllib.urlopen('%s/%s.xml' % (baseurl, self['SourcePackage'])).read()
+                except:
+                    return None
+            else:
+                return None
 
         try:
             dom = xml.dom.minidom.parseString(patterns)
@@ -779,6 +796,17 @@ class Report(ProblemReport):
 
             return title
 
+        if self.get('ProblemType') == 'KernelOops' and \
+            self.has_key('OopsText'):
+
+            oops = self['OopsText']
+            if oops.startswith('------------[ cut here ]------------'):
+                title = oops.split('\n', 2)[1]
+            else:
+                title = oops.split('\n', 1)[0]
+
+            return title
+
         return None
 
     def obsolete_packages(self):
@@ -1264,7 +1292,7 @@ int main() { return f(42); }
             os.close(fd2)
 
             # create a test script which produces a core dump for us
-            open(script, 'w').write('''#!/bin/sh
+            open(script, 'w').write('''#!/bin/bash
 gdb --batch --ex 'generate-core-file %s' --pid $$ >/dev/null''' % coredump)
             os.chmod(script, 0755)
 
@@ -1274,7 +1302,7 @@ gdb --batch --ex 'generate-core-file %s' --pid $$ >/dev/null''' % coredump)
                 stdout=subprocess.PIPE) == 0
 
             pr = Report()
-            pr['InterpreterPath'] = '/bin/sh'
+            pr['InterpreterPath'] = '/bin/bash'
             pr['ExecutablePath'] = script
             pr['CoreDump'] = (coredump,)
             pr.add_gdb_info()
@@ -1336,6 +1364,12 @@ gdb --batch --ex 'generate-core-file %s' --pid $$ >/dev/null''' % coredump)
             self.assertEqual(r_bash.search_bug_patterns(pdir), 'http://bugtracker.net/bugs/2')
             self.assertEqual(r_coreutils.search_bug_patterns(pdir), 'http://bugtracker.net/bugs/3')
 
+            # match on source package
+            r_bash['Package'] = 'bash-static 1-2'
+            self.assertEqual(r_bash.search_bug_patterns(pdir), None)
+            r_bash['SourcePackage'] = 'bash'
+            self.assertEqual(r_bash.search_bug_patterns(pdir), 'http://bugtracker.net/bugs/2')
+
             # negative match cases
             r_bash['Package'] = 'bash 1-21'
             self.assertEqual(r_bash.search_bug_patterns(pdir), None,
@@ -1717,6 +1751,10 @@ baz()
         self.assertEqual(report.standard_title(),
             'bash crashed with SIGSEGV in foo()')
 
+        report = Report('KernelOops')
+        report['OopsText'] = '------------[ cut here ]------------\nkernel BUG at /tmp/oops.c:5!\ninvalid opcode: 0000 [#1] SMP'
+        self.assertEqual(report.standard_title(),'kernel BUG at /tmp/oops.c:5!')
+
     def test_obsolete_packages(self):
         '''Test obsolete_packages().'''
 
