@@ -84,10 +84,12 @@ class __AptDpkgPackageInfo(PackageInfo):
         this_os = lsb_release.communicate()[0].strip()
         assert lsb_release.returncode == 0
 
-        for o in self._cache(package).candidateOrigin:
-            # note: checking site for ppa is a hack until LP #140412 gets fixed
-            if o.origin == this_os and not o.site.startswith('ppa'):
-                return True
+        origins = self._cache(package).candidateOrigin
+        if origins: # might be None
+            for o in origins:
+                # note: checking site for ppa is a hack until LP #140412 gets fixed
+                if o.origin == this_os and not o.site.startswith('ppa'):
+                    return True
         return False
 
     def get_architecture(self, package):
@@ -273,6 +275,14 @@ class __AptDpkgPackageInfo(PackageInfo):
 
         return root
 
+    def get_kernel_package(self):
+        '''Return the actual Linux kernel package name.
+
+        This is used when the user reports a bug against the "linux" package.
+        '''
+        # TODO: Ubuntu specific
+        return 'linux-image-' + os.uname()[2]
+
     #
     # Internal helper methods
     #
@@ -630,6 +640,10 @@ bo/gu/s                                                 na/mypackage
             self.assertEqual(impl.enabled(), True)
             f.close()
 
+        def test_get_kernel_pacakge(self):
+            '''Test get_kernel_package().'''
+
+            self.assert_('linux' in impl.get_kernel_package())
 
     # only execute if dpkg is available
     try:
