@@ -14,9 +14,12 @@ the full text of the license.
 import apport.packaging
 
 def add_info(report):
-    if apport.packaging.get_version('automatix') or \
-        apport.packaging.get_version('automatix2'):
-        report['UnreportableReason'] = 'You have installed automatix on your \
+    try:
+        if apport.packaging.get_version('automatix') or \
+            apport.packaging.get_version('automatix2'):
+            report['UnreportableReason'] = 'You have installed automatix on your \
 system. This is known to cause a lot of instability, thus problem reports \
 will not be sent to the %s developers.' % report.get('DistroRelease',
     'distribution').split()[0]
+    except ValueError, e:
+        return
